@@ -90,8 +90,8 @@ class Transact(models.Model):
     create_transact_id = year_timestamp() + zero_code
 
     # transact_id = models.BigIntegerField(verbose_name='交易号', unique=True, db_index=True, default=create_transact_id) # 应为transact号
-    transact_id = models.CharField(verbose_name='交易号', unique=True, max_length=255, blank=True, db_index=True)
-    enroll_id = models.BigIntegerField(verbose_name='交易号', db_index=True, null=True, )  # 应为transact号
+    transact_no = models.CharField(verbose_name='交易号', unique=True, max_length=255, blank=True, db_index=True)
+    enroll_id = models.BigIntegerField(verbose_name='报名id', db_index=True, null=True, )  # 应为transact号
     # transact_id = models.BigIntegerField(verbose_name='交易号', unique=True, db_index=True, default='') # 应为transact号
     transact_time = models.DateTimeField(verbose_name='交易时间', auto_now_add=True)
     # platform = models.ForeignKey(verbose_name='平台', to=Platform, db_column='platform_id', on_delete=models.DO_NOTHING, default='')
